@@ -55,6 +55,7 @@ struct _CountdownHomeWidgetPrivate
     GtkWidget *homeWidget;
     GtkWidget *contents;
 	GtkWidget *buttons;
+	GtkWidget *addButton;
 	GtkWidget *upButton, *downButton;
     GtkListStore *entries;
     guint refresh;
@@ -70,6 +71,9 @@ struct _CountdownHomeWidgetPrivate
 	gchar *leftText, *agoText;
 	guint offset;
     guint eventID;
+	
+	gboolean upButtonPressed, downButtonPressed, addButtonPressed;
+	gboolean eventPressed;
 };
 
 HD_DEFINE_PLUGIN_MODULE (CountdownHomeWidget, countdown_home_widget,
@@ -1093,6 +1097,7 @@ void countdown_home_widget_scroll_up (GtkWidget *button, GdkEventButton *event,
 	//g_warning ("countdown_home_widget_scroll_up");
 	self->priv->offset--;
 	countdown_home_widget_update_content (self);
+	self->priv->upButtonPressed = FALSE;
 }
 
 void countdown_home_widget_scroll_down (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
@@ -1100,6 +1105,49 @@ void countdown_home_widget_scroll_down (GtkWidget *button, GdkEventButton *event
 	//g_warning ("countdown_home_widget_scroll_down");
 	self->priv->offset++;
 	countdown_home_widget_update_content (self);
+	self->priv->downButtonPressed = FALSE;
+}
+
+void countdown_home_widget_up_button_press (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->upButtonPressed = TRUE;
+	gtk_widget_queue_draw (button);
+}
+
+void countdown_home_widget_up_leave_notify (GtkWidget *button, GdkEventCrossing *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->upButtonPressed = FALSE;
+	gtk_widget_queue_draw (button);
+}
+
+void countdown_home_widget_down_button_press (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->downButtonPressed = TRUE;
+	gtk_widget_queue_draw (button);
+}
+
+void countdown_home_widget_down_leave_notify (GtkWidget *button, GdkEventCrossing *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->downButtonPressed = FALSE;
+	gtk_widget_queue_draw (button);
+}
+
+void countdown_home_widget_add_button_press (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->addButtonPressed = TRUE;
+	gtk_widget_queue_draw (button);
+}
+
+void countdown_home_widget_add_leave_notify (GtkWidget *button, GdkEventCrossing *event, CountdownHomeWidget *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->addButtonPressed = FALSE;
+	gtk_widget_queue_draw (button);
 }
 
 void countdown_home_widget_content_create (CountdownHomeWidget *self)
@@ -1109,10 +1157,10 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
     self->priv->contents = gtk_vbox_new (TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 
-    GtkWidget *addNewCountdown = gtk_image_new_from_icon_name ("general_add", HILDON_ICON_SIZE_FINGER);
+    self->priv->addButton = gtk_image_new_from_icon_name ("general_add", HILDON_ICON_SIZE_FINGER);
 	GtkWidget *addEvent = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (addEvent), FALSE);
-	gtk_container_add (GTK_CONTAINER (addEvent), addNewCountdown);
+	gtk_container_add (GTK_CONTAINER (addEvent), self->priv->addButton);
 
     self->priv->buttons = gtk_hbox_new (TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->buttons), 0);
@@ -1128,13 +1176,20 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
 	gtk_container_add (GTK_CONTAINER (self->priv->downButton), downImage);
 	
 	g_signal_connect (self->priv->upButton, "button-release-event", G_CALLBACK (countdown_home_widget_scroll_up), self);
+	g_signal_connect (self->priv->upButton, "button-press-event", G_CALLBACK (countdown_home_widget_up_button_press), self);
+	g_signal_connect (self->priv->upButton, "leave-notify-event", G_CALLBACK (countdown_home_widget_up_leave_notify), self);
+	
 	g_signal_connect (self->priv->downButton, "button-release-event", G_CALLBACK (countdown_home_widget_scroll_down), self);
+	g_signal_connect (self->priv->downButton, "button-press-event", G_CALLBACK (countdown_home_widget_down_button_press), self);
+	g_signal_connect (self->priv->downButton, "leave-notify-event", G_CALLBACK (countdown_home_widget_down_leave_notify), self);
 	
 	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (addEvent));
 	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (self->priv->upButton));
 	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (self->priv->downButton));
     
     g_signal_connect (addEvent, "button-release-event", G_CALLBACK (countdown_home_widget_add_event), self);
+	g_signal_connect (addEvent, "button-press-event", G_CALLBACK (countdown_home_widget_add_button_press), self);
+	g_signal_connect (addEvent, "leave-notify-event", G_CALLBACK (countdown_home_widget_add_leave_notify), self);
     
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self->priv->homeWidget), align);
@@ -1142,6 +1197,10 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
 	
 	g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), self);
 	
+	self->priv->upButtonPressed = FALSE;
+	self->priv->downButtonPressed = FALSE;
+	self->priv->addButtonPressed = FALSE;
+	
     gtk_widget_show_all (self->priv->homeWidget);
 }
 
@@ -1465,6 +1524,81 @@ static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, Gdk
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
 	cairo_fill(cr);
+	
+	if (self->priv->addButtonPressed) {
+		GdkColor color;
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		
+		gint width, height, x, y;
+		width = widget->allocation.width;
+		height = widget->allocation.height;
+		x = widget->allocation.x;
+		y = widget->allocation.y;
+
+		cairo_move_to(cr, x + self->priv->radius, y);
+		cairo_line_to(cr, x + width, y);
+		cairo_line_to(cr, x + width, y + height - self->priv->radius);
+		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+					y + height, x + width - self->priv->radius, y + height);
+		cairo_line_to(cr, x + self->priv->radius, y + height);
+		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+					y + height - self->priv->radius);
+		cairo_line_to(cr, x, y);
+	
+		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+		cairo_fill (cr);
+	}
+	
+	if (self->priv->upButtonPressed) {
+		GdkColor color;
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		
+		gint width, height, x, y;
+		width = widget->allocation.width;
+		height = widget->allocation.height;
+		x = widget->allocation.x;
+		y = widget->allocation.y;
+
+		cairo_move_to(cr, x + self->priv->radius, y);
+		cairo_line_to(cr, x + width, y);
+		cairo_line_to(cr, x + width, y + height - self->priv->radius);
+		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+					y + height, x + width - self->priv->radius, y + height);
+		cairo_line_to(cr, x + self->priv->radius, y + height);
+		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+					y + height - self->priv->radius);
+		cairo_line_to(cr, x, y);
+	
+		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+		cairo_fill (cr);
+	}
+	
+	if (self->priv->downButtonPressed) {
+		GdkColor color;
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		
+		gint width, height, x, y;
+		width = widget->allocation.width;
+		height = widget->allocation.height;
+		x = widget->allocation.x;
+		y = widget->allocation.y;
+
+		cairo_move_to(cr, x + self->priv->radius, y);
+		cairo_line_to(cr, x + width, y);
+		cairo_line_to(cr, x + width, y + height - self->priv->radius);
+		cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+					y + height, x + width - self->priv->radius, y + height);
+		cairo_line_to(cr, x + self->priv->radius, y + height);
+		cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+					y + height - self->priv->radius);
+		cairo_line_to(cr, x, y);
+	
+		cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+		cairo_fill (cr);
+	}
 
     cairo_destroy (cr);
 	
@@ -1489,7 +1623,7 @@ static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventE
 	if (self->priv->systemBG) {
 		GdkColor color;
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
 	} else {
 		GdkColor color;
 		gdk_color_parse (self->priv->bgColor, &color);
